Index: trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/AutoQUESTPlugin.java
===================================================================
--- trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/AutoQUESTPlugin.java	(revision 929)
+++ trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/AutoQUESTPlugin.java	(revision 929)
@@ -0,0 +1,51 @@
+//   Copyright 2012 Georg-August-Universität Göttingen, Germany
+//
+//   Licensed under the Apache License, Version 2.0 (the "License");
+//   you may not use this file except in compliance with the License.
+//   You may obtain a copy of the License at
+//
+//       http://www.apache.org/licenses/LICENSE-2.0
+//
+//   Unless required by applicable law or agreed to in writing, software
+//   distributed under the License is distributed on an "AS IS" BASIS,
+//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+//   See the License for the specific language governing permissions and
+//   limitations under the License.
+
+package de.ugoe.cs.autoquest.plugin;
+
+import java.util.List;
+
+/**
+ * <p>
+ * Interface for AutoQUEST plug-ins.
+ * </p>
+ * 
+ * @author Steffen Herbold
+ * @version 1.0
+ */
+public interface AutoQUESTPlugin {
+
+	/**
+	 * <p>
+	 * Title of the plug-in.
+	 * </p>
+	 * 
+	 * @return the title
+	 */
+	public String getTitle();
+
+	/**
+	 * <p>
+	 * {@link List} of {@link String}s that contain the commands defined by this
+	 * plug-in. The List is immutable.
+	 * </p>
+	 * <p>
+	 * Consult the de.ugoe.cs.utils.console package of the java-utils project
+	 * for more information.
+	 * </p>
+	 * 
+	 * @return the command packages
+	 */
+	public List<String> getCommandPackages();
+}
Index: trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/PluginLoaderException.java
===================================================================
--- trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/PluginLoaderException.java	(revision 927)
+++ trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/PluginLoaderException.java	(revision 929)
@@ -18,5 +18,5 @@
  * <p>
  * This exception is thrown in case there is an error during the loading of
- * QUEST plugins. Note that the failures during the loading may result in an
+ * AutoQUEST plugins. Note that the failures during the loading may result in an
  * invalid classpath and this exception should, therefore, be treated with
  * appropriate care.
Index: trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/QuestPlugin.java
===================================================================
--- trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/QuestPlugin.java	(revision 927)
+++ 	(revision )
@@ -1,51 +1,0 @@
-//   Copyright 2012 Georg-August-Universität Göttingen, Germany
-//
-//   Licensed under the Apache License, Version 2.0 (the "License");
-//   you may not use this file except in compliance with the License.
-//   You may obtain a copy of the License at
-//
-//       http://www.apache.org/licenses/LICENSE-2.0
-//
-//   Unless required by applicable law or agreed to in writing, software
-//   distributed under the License is distributed on an "AS IS" BASIS,
-//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-//   See the License for the specific language governing permissions and
-//   limitations under the License.
-
-package de.ugoe.cs.autoquest.plugin;
-
-import java.util.List;
-
-/**
- * <p>
- * Interface for QUEST plug-ins.
- * </p>
- * 
- * @author Steffen Herbold
- * @version 1.0
- */
-public interface QuestPlugin {
-
-	/**
-	 * <p>
-	 * Title of the plug-in.
-	 * </p>
-	 * 
-	 * @return the title
-	 */
-	public String getTitle();
-
-	/**
-	 * <p>
-	 * {@link List} of {@link String}s that contain the commands defined by this
-	 * plug-in. The List is immutable.
-	 * </p>
-	 * <p>
-	 * Consult the de.ugoe.cs.utils.console package of the java-utils project
-	 * for more information.
-	 * </p>
-	 * 
-	 * @return the command packages
-	 */
-	public List<String> getCommandPackages();
-}

Index: trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/PluginLoader.java
===================================================================
--- trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/PluginLoader.java	(revision 927)
+++ trunk/autoquest-plugin-core/src/main/java/de/ugoe/cs/autoquest/plugin/PluginLoader.java	(revision 929)
@@ -33,5 +33,5 @@
 /**
  * <p>
  * This class provides the functionality to load QUEST plug-ins from a
  * pre-defined folder.
  * </p>
@@ -54,5 +54,5 @@
 	 * </p>
 	 */
-	private final Collection<QuestPlugin> plugins;
+	private final Collection<AutoQUESTPlugin> plugins;
 
 	/**
@@ -77,5 +77,5 @@
 		}
 		this.pluginDir = pluginDir;
-		plugins = new LinkedList<QuestPlugin>();
+		plugins = new LinkedList<AutoQUESTPlugin>();
 	}
 
@@ -112,5 +112,5 @@
 			}
 			try {
-				QuestPlugin pluginObject = (QuestPlugin) pluginClass
+				AutoQUESTPlugin pluginObject = (AutoQUESTPlugin) pluginClass
 						.newInstance();
 				plugins.add(pluginObject);
@@ -123,5 +123,5 @@
 			} catch (ClassCastException e) {
 				throw new PluginLoaderException("Class " + pluginClassName
-						+ " not instance of QuestPlugin");
+						+ " not instance of AutoQUESTPlugin");
 			}
 		}
@@ -232,5 +232,5 @@
 	/**
 	 * <p>
 	 * Checks if the name of a file indicates that it defines a QUEST plug-in.
 	 * The structure of valid plug-in filenames is
 	 * <code>quest-plugin-%PLUGIN_NAME%-version.jar</code>, where
@@ -241,5 +241,5 @@
 	 * @param filename
 	 *            filename that is checked
 	 * @return true if filename matches pattern of QUEST plug-in; false
 	 *         otherwise
 	 */
@@ -254,5 +254,5 @@
 	}
 	
-	public Collection<QuestPlugin> getPlugins() {
+	public Collection<AutoQUESTPlugin> getPlugins() {
 		return Collections.unmodifiableCollection(plugins);
 	}
@@ -33,5 +33,5 @@
 /**
  * <p>
- * This class provides the functionality to load QUEST plug-ins from a
+ * This class provides the functionality to load AutoQUEST plug-ins from a
  * pre-defined folder.
  * </p>
@@ -232,5 +232,5 @@
 	/**
 	 * <p>
-	 * Checks if the name of a file indicates that it defines a QUEST plug-in.
+	 * Checks if the name of a file indicates that it defines a AutoQUEST plug-in.
 	 * The structure of valid plug-in filenames is
 	 * <code>quest-plugin-%PLUGIN_NAME%-version.jar</code>, where
@@ -241,5 +241,5 @@
 	 * @param filename
 	 *            filename that is checked
-	 * @return true if filename matches pattern of QUEST plug-in; false
+	 * @return true if filename matches pattern of AutoQUEST plug-in; false
 	 *         otherwise
 	 */